@@ -34,7 +34,7 @@ from tinydav.exception import HTTPError, HTTPUserError, HTTPServerError
 
 __author__ = "Manuel Hermann <manuel-hermann@gmx.net>"
 __license__ = "LGPL"
-__version__ = "0.6.3"
+__version__ = "0.6.4"
 
 __all__ = (
     "HTTPError", "HTTPUserError", "HTTPServerError",
@@ -195,7 +195,7 @@ class WebDAVResponse(HTTPResponse):
 
         """
         try:
-            if self._content is None:
+            if self.content is None:
                 parse_me = self.response
             else:
                 parse_me = StringIO(self.content)
